@@ -2,24 +2,27 @@ package TestApReq::big_input;
 
 use strict;
 use warnings FATAL => 'all';
-use Apache::Request ();
-use Apache::RequestIO;
-use Apache::RequestRec;
+use Apache2::Request ();
+use Apache2::RequestIO;
+use Apache2::RequestRec;
+
+use Apache2::Const -compile => qw(OK);
 
 sub handler {
     my $r = shift;
-    my $req = Apache::Request->new($r);
+    my $req = Apache2::Request->new($r);
     my $len = 0;
 
     for ($req->param) {
-        $len += length($_) + length($req->param($_)) + 2; # +2 ('=' and '&')
+        my $val = $req->param($_) || '';
+        $len += length($_) + length($val) + 2; # +2 ('=' and '&')
     }
     $len--; # the stick with two ends one '&' char off
 
     $req->content_type('text/plain');
     $req->print($len);
 
-    return 0;
+    return Apache2::Const::OK;
 }
 
 1;
