@@ -20,7 +20,7 @@
 #include "at.h"
 
 
-static void test_strerror(dAT)
+static void test_strerror(dAT, void *ctx)
 {
     char buf[256], *str;
 
@@ -60,7 +60,7 @@ static void test_strerror(dAT)
 
  }
 
-#define dT(func, plan) #func, func, plan
+#define dT(func, plan) #func, func, plan, NULL
 
 
 int main(int argc, char *argv[])
@@ -77,7 +77,7 @@ int main(int argc, char *argv[])
 
     apr_pool_create(&p, NULL);
 
-    AT = at_create(p, 0, at_report_stdout_make(p));
+    AT = at_create(0, at_report_stdout_make());
 
     for (i = 0; i < sizeof(test_list) / sizeof(at_test_t);  ++i)
         plan += test_list[i].plan;
